#ifndef _CONFIG_H
#define _CONFIG_H

// Various routines that deal with parsing the configuration file.

#include <stddef.h>
#include <string>
#include <vector>

struct MarkPoolConfig {
	int from, to;
};

struct StreamConfig {
	std::string stream_id;
	std::string src;  // Can be empty.
	size_t backlog_size;
	int mark_pool;  // -1 for none.
};

struct AcceptorConfig {
	int port;
};

struct LogConfig {
	enum { LOG_TYPE_FILE, LOG_TYPE_CONSOLE, LOG_TYPE_SYSLOG } type;
	std::string filename;
};

struct Config {
	bool daemonize;
	int num_servers;
	std::vector<MarkPoolConfig> mark_pools;
	std::vector<StreamConfig> streams;
	std::vector<AcceptorConfig> acceptors;
	std::vector<LogConfig> log_destinations;

	std::string stats_file;  // Empty means no stats file.
	int stats_interval;
};

// Parse and validate configuration. Returns false on error.
// <config> is taken to be empty (uninitialized) on entry.
bool parse_config(const std::string &filename, Config *config);

#endif  // !defined(_CONFIG_H)
